==> geant4.9.6.p03.tar.gz: geant4.9.6.p03/source/persistency/mctruth/src/G4VPDigitIO.cc <==
//
// ********************************************************************
// * License and Disclaimer                                           *
// *                                                                  *
// * The  Geant4 software  is  copyright of the Copyright Holders  of *
// * the Geant4 Collaboration.  It is provided  under  the terms  and *
// * conditions of the Geant4 Software License,  included in the file *
// * LICENSE and available at  http://cern.ch/geant4/license .  These *
// * include a list of copyright holders.                             *
// *                                                                  *
// * Neither the authors of this software system, nor their employing *
// * institutes,nor the agencies providing financial support for this *
// * work  make  any representation or  warranty, express or implied, *
// * regarding  this  software system or assume any liability for its *
// * use.  Please see the license in the file  LICENSE  and URL above *
// * for the full disclaimer and the limitation of liability.         *
// *                                                                  *
// * This  code  implementation is the result of  the  scientific and *
// * technical work of the GEANT4 collaboration.                      *
// * By using,  copying,  modifying or  distributing the software (or *
// * any work based  on the software)  you  agree  to acknowledge its *
// * use  in  resulting  scientific  publications,  and indicate your *
// * acceptance of all terms of the Geant4 Software license.          *
// ********************************************************************
//
// File: G4VPDigitIO.cc
//
// History:
//   '01.08.10  Youhei Morita  Initial creation (with "fadsclass3")

#include "G4VPDigitIO.hh"

G4VPDigitIO* G4VPDigitIO::f_G4VPDigitIO = 0;

// Implementation of Constructor #1
G4VPDigitIO::G4VPDigitIO()
 : m_verbose(0)
{
  f_catalog = G4DCIOcatalog::GetDCIOcatalog();
}

// Implementation of SetVerboseLevel
void G4VPDigitIO::SetVerboseLevel(int v)
{
  m_verbose = v;

  // Loop through the registered Digit I/O managers
  for ( size_t i=0; i < f_catalog->NumberOfDCIOmanager(); i++ ) {
    G4VPDigitsCollectionIO* digitIOman = f_catalog->GetDCIOmanager(i);
    digitIOman->SetVerboseLevel(v);
  }
}

// End of G4VPDigitIO.cc

==> geant4.10.01.tar.gz: geant4.10.01/source/persistency/mctruth/src/G4VPDigitIO.cc <==
//
// ********************************************************************
// * License and Disclaimer                                           *
// *                                                                  *
// * The  Geant4 software  is  copyright of the Copyright Holders  of *
// * the Geant4 Collaboration.  It is provided  under  the terms  and *
// * conditions of the Geant4 Software License,  included in the file *
// * LICENSE and available at  http://cern.ch/geant4/license .  These *
// * include a list of copyright holders.                             *
// *                                                                  *
// * Neither the authors of this software system, nor their employing *
// * institutes,nor the agencies providing financial support for this *
// * work  make  any representation or  warranty, express or implied, *
// * regarding  this  software system or assume any liability for its *
// * use.  Please see the license in the file  LICENSE  and URL above *
// * for the full disclaimer and the limitation of liability.         *
// *                                                                  *
// * This  code  implementation is the result of  the  scientific and *
// * technical work of the GEANT4 collaboration.                      *
// * By using,  copying,  modifying or  distributing the software (or *
// * any work based  on the software)  you  agree  to acknowledge its *
// * use  in  resulting  scientific  publications,  and indicate your *
// * acceptance of all terms of the Geant4 Software license.          *
// ********************************************************************
//
// File: G4VPDigitIO.cc
//
// History:
//   '01.08.10  Youhei Morita  Initial creation (with "fadsclass3")

#include "G4VPDigitIO.hh"

G4ThreadLocal G4VPDigitIO* G4VPDigitIO::f_G4VPDigitIO = 0;

// Implementation of Constructor #1
G4VPDigitIO::G4VPDigitIO()
 : m_verbose(0)
{
  f_catalog = G4DCIOcatalog::GetDCIOcatalog();
}

// Implementation of SetVerboseLevel
void G4VPDigitIO::SetVerboseLevel(int v)
{
  m_verbose = v;

  // Loop through the registered Digit I/O managers
  for ( size_t i=0; i < f_catalog->NumberOfDCIOmanager(); i++ ) {
    G4VPDigitsCollectionIO* digitIOman = f_catalog->GetDCIOmanager(i);
    digitIOman->SetVerboseLevel(v);
  }
}

// End of G4VPDigitIO.cc
